from astropy.modeling import models
import numpy
import matplotlib.pyplot as plt

best_focus = -571.483741871
mode_name = 'IM__Red__g-SDSS'

data = {'file': ['0186_focus_gp.fits',
                 '0187_focus_gp.fits',
                 '0188_focus_gp.fits',
                 '0189_focus_gp.fits',
                 '0190_focus_gp.fits',
                 '0191_focus_gp.fits',
                 '0192_focus_gp.fits',
                 '0193_focus_gp.fits',
                 '0194_focus_gp.fits',
                 '0195_focus_gp.fits'],
        'fwhm': [5.291526,
                 4.712950,
                 4.112902,
                 3.449884,
                 2.930342,
                 2.665300,
                 2.579470,
                 2.611492,
                 2.815271,
                 3.246117],
        'focus': [-1496,
                  -1344,
                  -1197,
                  -1045,
                  -896,
                  -745,
                  -598,
                  -447,
                  -299,
                  -148]
        }

polynomial = models.Polynomial1D(degree=5)
polynomial.c0.value = 3.93919764664
polynomial.c1.value = 0.00602356641338
polynomial.c2.value = 1.04158253e-05
polynomial.c3.value = 1.16769514e-08
polynomial.c4.value = 9.45592111846e-12
polynomial.c5.value = 2.8321431518e-15

fig, ax = plt.subplots(figsize=(10,7))

ax.plot(data['focus'], data['fwhm'], marker='x', label='Measured FWHM')
ax.axvline(best_focus, color='k', label='Best Focus')
ax.set_title("Best Focus:\n{} {:.3f}".format(mode_name, best_focus))
ax.set_xlabel("Focus Value")
ax.set_ylabel("FWHM or Mean FWHM")

poly_x_axis = numpy.linspace(data['focus'][0], data['focus'][-1], 1000)

ax.plot(poly_x_axis, polynomial(poly_x_axis), label='Model')

ax.legend(loc='best')